@@ -116,7 +116,41 @@ function getTypeOf(v) {
  * derived from QWidget.
  */
 function isOfType(obj, type) {
-    return !isNull(obj) && obj.constructor===type;
+    if (RSettings.getQtVersion() < 0x060000) {
+        return !isNull(obj) && obj.constructor===type;
+    }
+    else {
+        //return !isNull(obj) && (obj.constructor===type || (isFunction(obj.getObjectType) && obj.getObjectType()===type.getObjectType()));
+        return !isNull(obj) && isFunction(obj.getObjectType) && obj.getObjectType()===type.getObjectType();
+    }
+}
+
+/**
+ * Destroys the given object with C++ ownership.
+ */
+function destr(obj) {
+    if (!RSettings.isQt(6)) {
+        obj.destroy();
+    }
+    else {
+        // destroy does not work in Qt 6 / QJSEngine:
+        // ("Invalid attempt to destroy() an indestructible object")
+        obj.destr();
+    }
+}
+
+/**
+ * Get pointer from shared pointer object using data() (Qt5) or implicitly (Qt6).
+ */
+function getPtr(p) {
+    if (RSettings.getQtVersion() > 0x060000) {
+        return p;
+    }
+    else {
+        if (isFunction(p.data)) {
+            return p.data();
+        }
+    }
 }
 
 /**
@@ -130,8 +164,13 @@ function isNull(obj) {
         return true;
     }
 
-    return (obj==null ||
-            (typeof(obj.isNull)==="function" && obj.isNull()===true));
+    return (
+        obj==null ||
+        // wrapped object is NULL:
+        (typeof(obj.isNullWrapper)==="function" && obj.isNullWrapper()===true) ||
+        // shared pointer is NULL:
+        (typeof(obj.data)==="function" && typeof(obj.isNull)==="function" && obj.isNull()===true)
+    );
 }
 
 /**
@@ -246,7 +285,12 @@ function isSeparator(obj) {
  * \return true if the given object is a layer.
  */
 function isLayer(obj) {
-    return isOfType(obj, RLayer) || isOfType(obj, RLayerPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLayer) || isOfType(obj, RLayerPointer);
+    }
+    else {
+        return isOfType(obj, RLayer);
+    }
 }
 
 /**
@@ -255,7 +299,12 @@ function isLayer(obj) {
  * \return true if the given object is a block.
  */
 function isBlock(obj) {
-    return isOfType(obj, RBlock) || isOfType(obj, RBlockPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RBlock) || isOfType(obj, RBlockPointer);
+    }
+    else {
+        return isOfType(obj, RBlock);
+    }
 }
 
 /**
@@ -264,7 +313,12 @@ function isBlock(obj) {
  * \return true if the given object is a layout.
  */
 function isLayout(obj) {
-    return isOfType(obj, RLayout) || isOfType(obj, RLayoutPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLayout) || isOfType(obj, RLayoutPointer);
+    }
+    else {
+        return isOfType(obj, RLayout);
+    }
 }
 
 /**
@@ -314,7 +368,12 @@ function isDimensionEntity(obj) {
  * (RDimDiametricEntity).
  */
 function isDimDiametricEntity(obj) {
-    return isOfType(obj, RDimDiametricEntity) || isOfType(obj, RDimDiametricEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimDiametricEntity) || isOfType(obj, RDimDiametricEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimDiametricEntity);
+    }
 }
 
 /**
@@ -324,7 +383,12 @@ function isDimDiametricEntity(obj) {
  * (RDimAlignedEntity).
  */
 function isDimAlignedEntity(obj) {
-    return isOfType(obj, RDimAlignedEntity) || isOfType(obj, RDimAlignedEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimAlignedEntity) || isOfType(obj, RDimAlignedEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimAlignedEntity);
+    }
 }
 
 /**
@@ -334,7 +398,12 @@ function isDimAlignedEntity(obj) {
  * (RDimRotatedEntity).
  */
 function isDimRotatedEntity(obj) {
-    return isOfType(obj, RDimRotatedEntity) || isOfType(obj, RDimRotatedEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimRotatedEntity) || isOfType(obj, RDimRotatedEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimRotatedEntity);
+    }
 }
 
 /**
@@ -344,7 +413,12 @@ function isDimRotatedEntity(obj) {
  * (RDimOrdinateEntity).
  */
 function isDimOrdinateEntity(obj) {
-    return isOfType(obj, RDimOrdinateEntity) || isOfType(obj, RDimOrdinateEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimOrdinateEntity) || isOfType(obj, RDimOrdinateEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimOrdinateEntity);
+    }
 }
 
 /**
@@ -354,7 +428,12 @@ function isDimOrdinateEntity(obj) {
  * (RDimRadialEntity).
  */
 function isDimRadialEntity(obj) {
-    return isOfType(obj, RDimRadialEntity) || isOfType(obj, RDimRadialEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimRadialEntity) || isOfType(obj, RDimRadialEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimRadialEntity);
+    }
 }
 
 /**
@@ -374,7 +453,12 @@ function isDimAngularEntity(obj) {
  * (RDimAngular2LEntity).
  */
 function isDimAngular2LEntity(obj) {
-    return isOfType(obj, RDimAngular2LEntity) || isOfType(obj, RDimAngular2LEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimAngular2LEntity) || isOfType(obj, RDimAngular2LEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimAngular2LEntity);
+    }
 }
 
 /**
@@ -384,7 +468,12 @@ function isDimAngular2LEntity(obj) {
  * (RDimAngular3PEntity).
  */
 function isDimAngular3PEntity(obj) {
-    return isOfType(obj, RDimAngular3PEntity) || isOfType(obj, RDimAngular3PEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimAngular3PEntity) || isOfType(obj, RDimAngular3PEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimAngular3PEntity);
+    }
 }
 
 /**
@@ -394,7 +483,12 @@ function isDimAngular3PEntity(obj) {
  * (RDimArcLengthEntity).
  */
 function isDimArcLengthEntity(obj) {
-    return isOfType(obj, RDimArcLengthEntity) || isOfType(obj, RDimArcLengthEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimArcLengthEntity) || isOfType(obj, RDimArcLengthEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimArcLengthEntity);
+    }
 }
 
 /**
@@ -404,7 +498,12 @@ function isDimArcLengthEntity(obj) {
  * (RDimLinearEntity).
  */
 function isDimLinearEntity(obj) {
-    return isOfType(obj, RDimLinearEntity) || isOfType(obj, RDimLinearEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimLinearEntity) || isOfType(obj, RDimLinearEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimLinearEntity);
+    }
 }
 
 /**
@@ -413,7 +512,12 @@ function isDimLinearEntity(obj) {
  * \return true if the given object is an arc entity (RHatchEntity).
  */
 function isHatchEntity(obj) {
-    return isOfType(obj, RHatchEntity) || isOfType(obj, RHatchEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RHatchEntity) || isOfType(obj, RHatchEntityPointer);
+    }
+    else {
+        return isOfType(obj, RHatchEntity);
+    }
 }
 
 /**
@@ -422,7 +526,12 @@ function isHatchEntity(obj) {
  * \return true if the given object is an arc entity (RArcEntity).
  */
 function isArcEntity(obj) {
-    return isOfType(obj, RArcEntity) || isOfType(obj, RArcEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RArcEntity) || isOfType(obj, RArcEntityPointer);
+    }
+    else {
+        return isOfType(obj, RArcEntity);
+    }
 }
 
 /**
@@ -431,7 +540,12 @@ function isArcEntity(obj) {
  * \return true if the given object is a line entity (RCircleEntity).
  */
 function isCircleEntity(obj) {
-    return isOfType(obj, RCircleEntity) || isOfType(obj, RCircleEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RCircleEntity) || isOfType(obj, RCircleEntityPointer);
+    }
+    else {
+        return isOfType(obj, RCircleEntity);
+    }
 }
 
 /**
@@ -440,7 +554,12 @@ function isCircleEntity(obj) {
  * \return true if the given object is an ellipse entity (REllipseEntity).
  */
 function isEllipseEntity(obj) {
-    return isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer);
+    }
+    else {
+        return isOfType(obj, REllipseEntity);
+    }
 }
 
 /**
@@ -467,7 +586,12 @@ function isFullEllipseEntity(obj) {
  * \return true if the given object is a line entity (RLineEntity).
  */
 function isLineEntity(obj) {
-    return isOfType(obj, RLineEntity) || isOfType(obj, RLineEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLineEntity) || isOfType(obj, RLineEntityPointer);
+    }
+    else {
+        return isOfType(obj, RLineEntity);
+    }
 }
 
 /**
@@ -485,7 +609,12 @@ function isLineBasedEntity(obj) {
  * \return true if the given object is an xline entity (RXLineEntity).
  */
 function isXLineEntity(obj) {
-    return isOfType(obj, RXLineEntity) || isOfType(obj, RXLineEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RXLineEntity) || isOfType(obj, RXLineEntityPointer);
+    }
+    else {
+        return isOfType(obj, RXLineEntity);
+    }
 }
 
 /**
@@ -494,7 +623,12 @@ function isXLineEntity(obj) {
  * \return true if the given object is a ray entity (RRayEntity).
  */
 function isRayEntity(obj) {
-    return isOfType(obj, RRayEntity) || isOfType(obj, RRayEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RRayEntity) || isOfType(obj, RRayEntityPointer);
+    }
+    else {
+        return isOfType(obj, RRayEntity);
+    }
 }
 
 /**
@@ -503,7 +637,12 @@ function isRayEntity(obj) {
  * \return true if the given object is a point entity (RPointEntity).
  */
 function isPointEntity(obj) {
-    return isOfType(obj, RPointEntity) || isOfType(obj, RPointEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RPointEntity) || isOfType(obj, RPointEntityPointer);
+    }
+    else {
+        return isOfType(obj, RPointEntity);
+    }
 }
 
 /**
@@ -512,14 +651,24 @@ function isPointEntity(obj) {
  * \return true if the given object is an image entity (RImageEntity).
  */
 function isImageEntity(obj) {
-    return isOfType(obj, RImageEntity) || isOfType(obj, RImageEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RImageEntity) || isOfType(obj, RImageEntityPointer);
+    }
+    else {
+        return isOfType(obj, RImageEntity);
+    }
 }
 
 /**
  * \return true if the given object is a polyline entity (RPolylineEntity).
  */
 function isPolylineEntity(obj) {
-    return isOfType(obj, RPolylineEntity) || isOfType(obj, RPolylineEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RPolylineEntity) || isOfType(obj, RPolylineEntityPointer);
+    }
+    else {
+        return isOfType(obj, RPolylineEntity);
+    }
 }
 
 /**
@@ -552,7 +701,12 @@ function isOpenPolylineEntity(obj, tolerance) {
  * \return true if the given object is a solid entity (RSolidEntity).
  */
 function isSolidEntity(obj) {
-    return isOfType(obj, RSolidEntity) || isOfType(obj, RSolidEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RSolidEntity) || isOfType(obj, RSolidEntityPointer);
+    }
+    else {
+        return isOfType(obj, RSolidEntity);
+    }
 }
 
 /**
@@ -561,7 +715,12 @@ function isSolidEntity(obj) {
  * \return true if the given object is a trace entity (RTraceEntity).
  */
 function isTraceEntity(obj) {
-    return isOfType(obj, RTraceEntity) || isOfType(obj, RTraceEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RTraceEntity) || isOfType(obj, RTraceEntityPointer);
+    }
+    else {
+        return isOfType(obj, RTraceEntity);
+    }
 }
 
 /**
@@ -570,7 +729,12 @@ function isTraceEntity(obj) {
  * \return true if the given object is a face entity (RFaceEntity).
  */
 function isFaceEntity(obj) {
-    return isOfType(obj, RFaceEntity) || isOfType(obj, RFaceEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RFaceEntity) || isOfType(obj, RFaceEntityPointer);
+    }
+    else {
+        return isOfType(obj, RFaceEntity);
+    }
 }
 
 /**
@@ -579,7 +743,12 @@ function isFaceEntity(obj) {
  * \return true if the given object is a viewport entity (RViewportEntity).
  */
 function isViewportEntity(obj) {
-    return isOfType(obj, RViewportEntity) || isOfType(obj, RViewportEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RViewportEntity) || isOfType(obj, RViewportEntityPointer);
+    }
+    else {
+        return isOfType(obj, RViewportEntity);
+    }
 }
 
 /**
@@ -588,7 +757,12 @@ function isViewportEntity(obj) {
  * \return true if the given object is a spline entity (RSplineEntity).
  */
 function isSplineEntity(obj) {
-    return isOfType(obj, RSplineEntity) || isOfType(obj, RSplineEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RSplineEntity) || isOfType(obj, RSplineEntityPointer);
+    }
+    else {
+        return isOfType(obj, RSplineEntity);
+    }
 }
 
 /**
@@ -624,7 +798,12 @@ function isTextBasedEntity(obj) {
  * \return true if the given object is a text entity (RTextEntity).
  */
 function isTextEntity(obj) {
-    return isOfType(obj, RTextEntity) || isOfType(obj, RTextEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RTextEntity) || isOfType(obj, RTextEntityPointer);
+    }
+    else {
+        return isOfType(obj, RTextEntity);
+    }
 }
 
 /**
@@ -642,7 +821,12 @@ function isSimpleTextEntity(obj) {
  * \return true if the given object is a block reference entity (RBlockReferenceEntity).
  */
 function isBlockReferenceEntity(obj) {
-    return isOfType(obj, RBlockReferenceEntity) || isOfType(obj, RBlockReferenceEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RBlockReferenceEntity) || isOfType(obj, RBlockReferenceEntityPointer);
+    }
+    else {
+        return isOfType(obj, RBlockReferenceEntity);
+    }
 }
 
 /**
@@ -651,7 +835,12 @@ function isBlockReferenceEntity(obj) {
  * \return true if the given object is an attribute definition entity (RAttributeDefinitionEntity).
  */
 function isAttributeDefinitionEntity(obj) {
-    return isOfType(obj, RAttributeDefinitionEntity) || isOfType(obj, RAttributeDefinitionEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RAttributeDefinitionEntity) || isOfType(obj, RAttributeDefinitionEntityPointer);
+    }
+    else {
+        return isOfType(obj, RAttributeDefinitionEntity);
+    }
 }
 
 /**
@@ -660,7 +849,12 @@ function isAttributeDefinitionEntity(obj) {
  * \return true if the given object is an attribute entity (RAttributeEntity).
  */
 function isAttributeEntity(obj) {
-    return isOfType(obj, RAttributeEntity) || isOfType(obj, RAttributeEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RAttributeEntity) || isOfType(obj, RAttributeEntityPointer);
+    }
+    else {
+        return isOfType(obj, RAttributeEntity);
+    }
 }
 
 /**
@@ -670,7 +864,12 @@ function isAttributeEntity(obj) {
  * (RLeaderEntity).
  */
 function isLeaderEntity(obj) {
-    return isOfType(obj, RLeaderEntity) || isOfType(obj, RLeaderEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLeaderEntity) || isOfType(obj, RLeaderEntityPointer);
+    }
+    else {
+        return isOfType(obj, RLeaderEntity);
+    }
 }
 
 /**
@@ -679,7 +878,12 @@ function isLeaderEntity(obj) {
  * \return true if the given object is a tolerance entity (RToleranceEntity).
  */
 function isToleranceEntity(obj) {
-    return isOfType(obj, RToleranceEntity) || isOfType(obj, RToleranceEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RToleranceEntity) || isOfType(obj, RToleranceEntityPointer);
+    }
+    else {
+        return isOfType(obj, RToleranceEntity);
+    }
 }
 
 /**
@@ -705,6 +909,10 @@ function isEntityType(obj, type) {
         }
     }
 
+    if (type===RS.EntityAll) {
+        return true;
+    }
+
     return false;
 }
 
@@ -734,7 +942,12 @@ function isDirectedShape(obj) {
  * \return true if the given object is an arc shape (RArc).
  */
 function isArcShape(obj) {
-    return isOfType(obj, RArc) || isOfType(obj, RArcPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RArc) || isOfType(obj, RArcPointer);
+    }
+    else {
+        return isOfType(obj, RArc);
+    }
 }
 
 /**
@@ -743,7 +956,12 @@ function isArcShape(obj) {
  * \return true if the given object is a circle shape (RCircle).
  */
 function isCircleShape(obj) {
-    return isOfType(obj, RCircle) || isOfType(obj, RCirclePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RCircle) || isOfType(obj, RCirclePointer);
+    }
+    else {
+        return isOfType(obj, RCircle);
+    }
 }
 
 /**
@@ -752,7 +970,12 @@ function isCircleShape(obj) {
  * \return true if the given object is an ellipse shape (REllipse).
  */
 function isEllipseShape(obj) {
-    return isOfType(obj, REllipse) || isOfType(obj, REllipsePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, REllipse) || isOfType(obj, REllipsePointer);
+    }
+    else {
+        return isOfType(obj, REllipse);
+    }
 }
 
 /**
@@ -788,7 +1011,12 @@ function isLineBasedShape(obj) {
  * \return true if the given object is a line shape (RLine).
  */
 function isLineShape(obj) {
-    return isOfType(obj, RLine) || isOfType(obj, RLinePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLine) || isOfType(obj, RLinePointer);
+    }
+    else {
+        return isOfType(obj, RLine);
+    }
 }
 
 /**
@@ -797,7 +1025,12 @@ function isLineShape(obj) {
  * \return true if the given object is an xline shape (RXLine).
  */
 function isXLineShape(obj) {
-    return isOfType(obj, RXLine) || isOfType(obj, RXLinePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RXLine) || isOfType(obj, RXLinePointer);
+    }
+    else {
+        return isOfType(obj, RXLine);
+    }
 }
 
 /**
@@ -806,7 +1039,12 @@ function isXLineShape(obj) {
  * \return true if the given object is a ray shape (RRay).
  */
 function isRayShape(obj) {
-    return isOfType(obj, RRay) || isOfType(obj, RRayPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RRay) || isOfType(obj, RRayPointer);
+    }
+    else {
+        return isOfType(obj, RRay);
+    }
 }
 
 /**
@@ -815,7 +1053,12 @@ function isRayShape(obj) {
  * \return true if the given object is a point shape (RPoint).
  */
 function isPointShape(obj) {
-    return isOfType(obj, RPoint) || isOfType(obj, RPointPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RPoint) || isOfType(obj, RPointPointer);
+    }
+    else {
+        return isOfType(obj, RPoint);
+    }
 }
 
 /**
@@ -824,7 +1067,12 @@ function isPointShape(obj) {
  * \return true if the given object is a polyline shape (RPolyline).
  */
 function isPolylineShape(obj) {
-    return isOfType(obj, RPolyline) || isOfType(obj, RPolylinePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RPolyline) || isOfType(obj, RPolylinePointer);
+    }
+    else {
+        return isOfType(obj, RPolyline);
+    }
 }
 
 /**
@@ -840,7 +1088,12 @@ function isClosedPolylineShape(obj) {
  * \return true if the given object is a spline shape (RSpline).
  */
 function isSplineShape(obj) {
-    return isOfType(obj, RSpline) || isOfType(obj, RSplinePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RSpline) || isOfType(obj, RSplinePointer);
+    }
+    else {
+        return isOfType(obj, RSpline);
+    }
 }
 
 /**
@@ -863,7 +1116,12 @@ function isClosedSplineShape(obj, tolerance) {
  * \return true if the given object is a triangle shape (RTriangle).
  */
 function isTriangleShape(obj) {
-    return isOfType(obj, RTriangle) || isOfType(obj, RTrianglePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RTriangle) || isOfType(obj, RTrianglePointer);
+    }
+    else {
+        return isOfType(obj, RTriangle);
+    }
 }
 
 /**
@@ -889,6 +1147,8 @@ function entityTypeToClass(type) {
         return "RLinetype";
     case RS.ObjectView:
         return "RView";
+    case RS.ObjectDimStyle:
+        return "RDimStyle";
 
     case RS.EntityAll:
         return "REntity";
@@ -1338,8 +1598,8 @@ function copyDirectory(sourceDirPath, destDirPath) {
     var files;
     var srcName;
     var destName;
-    var filterFlags = new QDir.Filters(QDir.Files);
-    var sortFlags = new QDir.SortFlags(QDir.NoSort);
+    var filterFlags = makeQDirFilters(QDir.Files);
+    var sortFlags = makeQDirSortFlags(QDir.NoSort);
     files = sourceDir.entryList(filterFlags, sortFlags);
     for(i = 0; i< files.length; i++) {
         srcName = sourceDirPath + QDir.separator + files[i];
@@ -1349,7 +1609,7 @@ function copyDirectory(sourceDirPath, destDirPath) {
         }
     }
 
-    var flags = new QDir.Filters(QDir.AllDirs, QDir.NoDotAndDotDot);
+    var flags = makeQDirFilters(QDir.AllDirs, QDir.NoDotAndDotDot);
     files = sourceDir.entryList(flags);
     for(i = 0; i< files.length; i++) {
         srcName = sourceDirPath + QDir.separator + files[i];
@@ -1368,8 +1628,7 @@ function removeDirectory(dirPath) {
     var dir = new QDir(dirPath);
     var hasErr = false;
     if (dir.exists()) {
-        var flags = new QDir.Filters(QDir.NoDotAndDotDot, 
-                QDir.Dirs, QDir.Files, QDir.Hidden);
+        var flags = makeQDirFilters(QDir.NoDotAndDotDot, QDir.Dirs, QDir.Files, QDir.Hidden);
         var entries = dir.entryInfoList(flags);
         for (var i = 0; i <  entries.length; i++) {
             var entryInfo = entries[i];
@@ -1414,14 +1673,14 @@ function findFile(dirPath, fileName, ignoreDirs) {
     var i;
     var files;
     var name;
-    var filterFlags = new QDir.Filters(QDir.Files);
-    var sortFlags = new QDir.SortFlags(QDir.NoSort);
+    var filterFlags = makeQDirFilters(QDir.Files);
+    var sortFlags = makeQDirSortFlags(QDir.NoSort);
     files = dir.entryList([fileName], filterFlags, sortFlags);
     for (i=0; i<files.length; i++) {
         res = res.concat(dirPath + QDir.separator + files[i]);
     }
 
-    var flags = new QDir.Filters(QDir.AllDirs, QDir.NoDotAndDotDot);
+    var flags = makeQDirFilters(QDir.AllDirs, QDir.NoDotAndDotDot);
     files = dir.entryList(flags);
     for (i = 0; i< files.length; i++) {
         var nextDir = dirPath + QDir.separator + files[i];
@@ -1631,7 +1890,7 @@ Array.prototype.removeIgnoreCase = function(val) {
 
 /**
  * Remove the given parameter from an array (by default 'undefined').
- * 
+ *
  * test = new Array("","One","Two","", "Three","","Four").clean("");
  *
  * test2 = [1,2,,3,,3,,,,,,4,,4,,5,,6,,,,];
@@ -1642,7 +1901,7 @@ Array.prototype.removeIgnoreCase = function(val) {
  */
 Array.prototype.clean = function(deleteValue) {
     for (var i = 0; i < this.length; i++) {
-        if (this[i] == deleteValue) {         
+        if (this[i] == deleteValue) {
             this.splice(i, 1);
             i--;
         }
@@ -1652,7 +1911,7 @@ Array.prototype.clean = function(deleteValue) {
 
 /**
  * Clones (copies) the array.
- * 
+ *
  * \returns the cloned array
  */
 Array.prototype.clone = function() {
@@ -1715,6 +1974,22 @@ Array.prototype.filter = function(func, thisArg) {
 //    });
 //};
 
+Array.union = function(x, y) {
+    var i;
+    var obj = {};
+    for (i=x.length-1; i>=0; --i) {
+        obj[x[i]] = x[i];
+    }
+    for (i=y.length-1; i>=0; --i) {
+        obj[y[i]] = y[i];
+    }
+    var res = []
+    for (var k in obj) {
+        res.push(obj[k]);
+    }
+    return res;
+};
+
 /* Finds the intersection of two sorted arrays.
  *
  * \param a first array, must already be sorted
@@ -1826,8 +2101,12 @@ String.prototype.trim = function() {
  */
 String.prototype.elidedText = function(font, pixel) {
     var fm = new QFontMetrics(font);
-    var t = fm.elidedText(this, Qt.ElideMiddle, pixel);
-    fm.destroy();
+    var s = this;
+    if (!isString(s)) {
+        s = s.toString();
+    }
+    var t = fm.elidedText(s, Qt.ElideMiddle, pixel);
+    destr(fm);
     // replace HORIZONTAL ELLIPSIS (not every GUI font has those):
     t = t.replace(/\u2026/g, '...');
     return t;
@@ -2774,6 +3053,16 @@ function applyTheme() {
     }
 }
 
+function setUtf8Codec(ts) {
+    if (RSettings.getQtVersion() >= 0x060000) {
+        ts.setEncoding(QStringConverter.Utf8);
+    }
+    else {
+        ts.setCodec("UTF-8");
+    }
+}
+
+
 function readTextFile(fileName) {
     var file = new QFile(fileName);
     var flags = new QIODevice.OpenMode(QIODevice.ReadOnly | QIODevice.Text);
@@ -2844,7 +3133,8 @@ function createSpatialIndex() {
 
 // Qt 4 API workaround:
 function qsTranslate2(context, sourceText, disambiguation, n) {
-    if (RSettings.isQt(4)) {
+    // Qt 4:
+    if (RSettings.getQtVersion() < 0x050000) {
         if (isNull(disambiguation)) {
             return qsTranslate(context, sourceText);
         }
@@ -2853,9 +3143,90 @@ function qsTranslate2(context, sourceText, disambiguation, n) {
         }
         return qsTranslate(context, sourceText, disambiguation, "UnicodeUTF8", n);
     }
+
+    // Qt > 5
     return qsTranslate(context, sourceText, disambiguation, n);
 }
 
+function makeQDirFilters() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QDir.Filters);
+    return makeFlags.apply(null, argumentsNew);
+}
+
+function makeQDirSortFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QDir.SortFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtMatchFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.MatchFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtToolBarAreas() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.ToolBarAreas);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtWindowFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.WindowFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtAlignment() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.Alignment);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQIODeviceOpenMode() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QIODevice.OpenMode);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQMessageBoxStandardButtons() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QMessageBox.StandardButtons);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtItemFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.ItemFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeFlags() {
+    if (RSettings.isQt(6)) {
+        var ret = 0;
+        for (var i=1; i<arguments.length; i++) {
+            ret |= arguments[i];
+        }
+        return ret;
+    }
+    else {
+        var argumentsNew = [].slice.call(arguments, 0);
+        var flgs = argumentsNew.shift();
+        return flgs.apply(this, argumentsNew);
+    }
+}
+
+function getQLocaleName(locale) {
+    if (isFunction(locale.name)) {
+        return locale.name();
+    }
+    else {
+        // QJSEngine does not allow "name" as function.
+        return locale.name2();
+    }
+}
+
 // fix QPlainTextEdit API for Qt 5:
 if (!isFunction(QPlainTextEdit.prototype.toPlainText)) {
     QPlainTextEdit.prototype.toPlainText = function() {
